@@ -6,8 +6,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_CONTACTCOMPLETIONMODEL_P_H
-#define AKONADI_CONTACTCOMPLETIONMODEL_P_H
+#pragma once
 
 #include <entitytreemodel.h>
 
@@ -39,4 +38,3 @@ private:
 };
 }
 
-#endif
