@@ -21,23 +21,23 @@ using namespace ContactEditor;
 NameWidget::NameWidget(QWidget *parent)
     : QWidget(parent)
 {
-    auto *topLayout = new QVBoxLayout(this);
+    auto topLayout = new QVBoxLayout(this);
     topLayout->setContentsMargins(0, 0, 0, 0);
-    QLabel *label = new QLabel(i18n("Name"));
+    auto label = new QLabel(i18n("Name"));
     label->setObjectName(QStringLiteral("namelabel"));
     topLayout->addWidget(label);
 
-    auto *lineLayout = new QHBoxLayout;
+    auto lineLayout = new QHBoxLayout;
     lineLayout->setContentsMargins(0, 0, 0, 0);
     topLayout->addLayout(lineLayout);
 
-    mNameEdit = new KLineEdit;
+    mNameEdit = new KLineEdit(this);
     mNameEdit->setTrapReturnKey(true);
     lineLayout->addWidget(mNameEdit);
     setFocusProxy(mNameEdit);
     setFocusPolicy(Qt::StrongFocus);
 
-    mButtonEdit = new QToolButton;
+    mButtonEdit = new QToolButton(this);
     mButtonEdit->setText(i18n("..."));
     mButtonEdit->setToolTip(i18n("Edit Contact Name"));
     lineLayout->addWidget(mButtonEdit);
