@@ -7,8 +7,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef PHONELISTWIDGET_H
-#define PHONELISTWIDGET_H
+#pragma once
 
 #include "contacteditor_private_export.h"
 #include <QWidget>
@@ -33,4 +32,3 @@ private:
     ContactEditor::PhoneWidgetLister *mPhoneWidgetLister = nullptr;
 };
 }
-#endif // PHONELISTWIDGET_H
